from django.conf.urls import patterns, include, url
from django.contrib.auth.views import logout
from django.core.urlresolvers import reverse_lazy

from account.views import home_view, login_view


urlpatterns = patterns('',
    url(r'^logout/$', logout, kwargs={'next_page': '/login/'}, name="account-logout"),
    url(r'^login/$', login_view, name="account-login"),
    url(r'^$', home_view, name="home"),
    url(r'', include('social_auth.urls')),
)



from urllib import urlencode, urlopen
from httplib2 import Http


def dsa_urlopen(*args, **kwargs):
    return urlopen(*args, **kwargs)

def facebook_request(url, access_token, params=None, data=None):
    h = Http()
    params = {} if params is None else params.copy()
    params['access_token'] = access_token
    url = url + '?' + urlencode(params)
    if data is None:
        resp, content = h.request(url, "GET")
    else:
        resp, content = h.request(url, "POST", urlencode(data))
    return content

FACEBOOK_API_URL = 'https://graph.facebook.com/'
FACEBOOK_FEED = 'me/feed'

def publish_to_facebook(user, contents):

    try:
        social_auth = user.social_auth.filter(provider="facebook")[0]
    except IndexError:
        raise Exception("No social auth profile available for this user.")

    token = social_auth.tokens['access_token']
    url = FACEBOOK_API_URL+FACEBOOK_FEED
    data = {
        "message": unicode(contents).encode('utf-8'),
    }
    result = facebook_request(url, token, data=data)
    return result




# -*- coding: utf8 -*-
from django.contrib.auth.decorators import login_required
from django.views.generic import TemplateView


home_view = login_required(TemplateView.as_view(template_name = "account/home.html"))
login_view = TemplateView.as_view(template_name='account/login-form.html')



# -*- coding: utf8 -*-
import re
import os
import sys

from setuptools import setup, find_packages

setup(
    name="django-carrots",
    version="1.7",
    packages=find_packages(),

    # Project uses reStructuredText, so ensure that the docutils get
    # installed or upgraded on the target machine
    install_requires=['django-social-auth3'],

    # metadata for upload to PyPI
    author=u"Krzysztof Płocharz",
    author_email="krzysztof@plocharz.info",
    description="Basic account application for Django Workshops by Geek Girl Carrots",
    license="PSF",
    keywords="django facebook account",
    url="http://geekgirlscarrots.pl/",
    include_package_data = True,
)
